<?php
/**
 * ownCloud Admin_Audit
 *
 * @author Sujith Haridasan <sharidasan@owncloud.com>
 * @copyright (C) 2018 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Admin_Audit\Handlers;

use OC\Files\Filesystem;

class Comments extends Base {

	static public function createComment($event) {
		self::logCreateComment('{actor} created comment for {type} "{file}" with fileid: {fileid}', $event);
	}

	static public function updateComment($event) {
		self::logUpdateComment('{actor} update comment with comment id {commentid} for {type} "{file}" with fileid: {fileid}', $event);
	}

	static public function deleteComment($event) {
		self::logDeleteComment('{actor} delete comment with comment id {commentid} for {type} "{file}" with fileid: {fileid}', $event);
	}

	static protected function logDeleteComment($message, $arguments) {
		$view = Filesystem::getView();
		if ($view->filetype($view->getPath($arguments['objectId'])) === 'dir') {
			$type = 'folder';
		} else {
			$type = 'file';
		}
		self::getLogger()->log($message, [
			'fileid' => $arguments['objectId'],
			'file' => $view->getPath($arguments['objectId']),
			'type' => $type,
			'commentid' => $arguments['commentId']
		]);
	}

	static protected function logCreateComment($message, $arguments) {
		$view = Filesystem::getView();
		if ($view->filetype($view->getPath($arguments['objectId'])) === 'dir') {
			$type = "folder";
		} else {
			$type = "file";
		}
		self::getLogger()->log($message, [
			'fileid' => $arguments['objectId'],
			'file' => $view->getPath($arguments['objectId']),
			'type' => $type
		]);
	}

	static protected function logUpdateComment($message, $arguments) {
		$view = Filesystem::getView();
		if ($view->filetype($view->getPath($arguments['objectId'])) === 'dir') {
			$type = "folder";
		} else {
			$type = "file";
		}
		self::getLogger()->log($message, [
			'file' => $view->getPath($arguments['objectId']),
			'fileid' => $arguments['objectId'],
			'type' => $type,
			'commentid' => $arguments['commentId']
		]);
	}
}