<?php

/**
 * @author Tom Needham <tom@owncloud.com>
 *
 * @copyright Copyright (c) 2017, ownCloud, GbmH.
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License, version 3,
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 *
 */

namespace OCA\Enterprise_Key;

use OCP\IL10N;
use OCP\Settings\ISettings;
use OCP\Template;

class AdminPanel implements ISettings
{

	/** @var IL10N  */
	protected $l;

	public function __construct(IL10N $l) {
		$this->l = $l;
	}

	public function getPanel() {
		$template = new Template('enterprise_key', 'settings');
		$messageClass = '';
		$key = new EnterpriseKey(false, \OC::$server->getConfig());
		if ($key->isValid() && $key->expiresInDays() > 0) {
			$expiresIn = $key->expiresInDays();
			$message = $this->l->t('The registered enterprise license key expires in %d days.', [$expiresIn]);
		} else {
			$messageClass = 'warning';
			$message = EnterpriseKey::getLicenseKeyNotice($key, true);
		}
		$template->assign('messageClass', $messageClass);
		$template->assign('message', $message);
		return $template;
	}

	public function getPriority() {
		return 20;
	}

	public function getSectionID() {
		return 'general';
	}

}
